@@ -3,8 +3,10 @@
 #![deny(broken_intra_doc_links)]
 #![deny(missing_docs)]
 
-#![cfg_attr(all(test, feature = "unstable"), feature(test))]
-#[cfg(all(test, feature = "unstable"))] extern crate test;
+#![cfg_attr(docsrs, feature(doc_auto_cfg))]
+
+#![cfg_attr(all(test, feature = "_bench_unstable"), feature(test))]
+#[cfg(all(test, feature = "_bench_unstable"))] extern crate test;
 
 mod util;
 
@@ -122,6 +124,12 @@ impl FilesystemPersister {
 					"Invalid ChannelMonitor file name",
 				));
 			}
+			if filename.unwrap().ends_with(".tmp") {
+				// If we were in the middle of committing an new update and crashed, it should be
+				// safe to ignore the update - we should never have returned to the caller and
+				// irrevocably committed to the new state in any way.
+				continue;
+			}
 
 			let txid = Txid::from_hex(filename.unwrap().split_at(64).0);
 			if txid.is_err() {
@@ -362,7 +370,7 @@ mod tests {
 	}
 }
 
-#[cfg(all(test, feature = "unstable"))]
+#[cfg(all(test, feature = "_bench_unstable"))]
 pub mod bench {
 	use test::Bencher;
 
